@@ -10,7 +10,34 @@ Cu.import("resource://gre/modules/ctypes.jsm");
 
 Cu.import("resource://unity/unity-global-property-initializer.js");
 
-var pbs = Cc["@mozilla.org/privatebrowsing;1"].getService(Ci.nsIPrivateBrowsingService);
+var pbs = (function () {
+    var privateBrowsingService = null;
+    function _tryGetDeprecatedPrivateBrowsingService () {
+        var service = null;
+        try {
+            service = Cc["@mozilla.org/privatebrowsing;1"].getService(Ci.nsIPrivateBrowsingService);
+            // validate that we are not using the dummy stub version: see https://bugzilla.mozilla.org/show_bug.cgi?id=826037#c16
+            // & https://bugzilla.mozilla.org/attachment.cgi?id=697195&action=diff
+            if (service !== null && !("privateBrowsingEnabled" in service))
+                service = null;
+        }
+        catch (e) {
+            // we are in the case where it has been removed and w/o the stub
+        }
+        return service;
+    }
+    privateBrowsingService = _tryGetDeprecatedPrivateBrowsingService();
+
+    function _makePrivateBrowsingWithBackend(backend) {
+        return { privateBrowsingEnabled: backend };
+    }
+    if (privateBrowsingService !== null)
+        return _makePrivateBrowsingWithBackend(function(aWindow) { return privateBrowsingService.privateBrowsingEnabled });
+
+    var privateBrowsingUtils = Cu.import('resource://gre/modules/PrivateBrowsingUtils.jsm', {}).PrivateBrowsingUtils;
+    return _makePrivateBrowsingWithBackend(function(aWindow) { return privateBrowsingUtils.isWindowPrivate(aWindow); });
+}) ();
+
 var observerService = Cc["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
 
 function BrandingRemover(mainWindow) {
@@ -119,6 +146,9 @@ WindowMonitor.prototype = {
     },
 
     _listenEvent: function(target, name, cb) {
+        if (!target || !cb)
+            return;
+
         var descr = { target: target, name: name, cb: cb.bind(this) };
 
         target.addEventListener(name, descr.cb, false);
@@ -213,7 +243,7 @@ Observer.prototype = {
 
     observe : function(aWindow, aTopic, aData) {
         if (aWindow instanceof Ci.nsIDOMWindow && aTopic == 'content-document-global-created') {
-            if (pbs.privateBrowsingEnabled)
+            if (pbs && pbs.privateBrowsingEnabled(aWindow))
                 return;
 
             UnityGlobalPropertyInitializer.handle(aWindow);
