@@ -19,15 +19,15 @@ UnityPopupManager.prototype.requestIntegration = function (document, name, domai
 						   message,
 						   null,
 						   { label: l10n.formatMessage('prompt.yes'),
-						     accessKey: "Y",
+						     accessKey: l10n.formatMessage('prompt.yesAccessKey'),
 						     callback: integrateCallback },
 						   [
 						       { label: l10n.formatMessage('prompt.no'),
-							 accessKey: "N",
+							 accessKey: l10n.formatMessage('prompt.noAccessKey'),
 							 callback: new Function() },
 
 						       { label: l10n.formatMessage('prompt.dontask'),
-							 accessKey: "D",
+							 accessKey: l10n.formatMessage('prompt.dontaskAccessKey'),
 							 callback: dontAskActionCallback }
 						   ]);
 
